summaryrefslogtreecommitdiff
path: root/service/entry.go
diff options
context:
space:
mode:
Diffstat (limited to 'service/entry.go')
-rw-r--r--service/entry.go11
1 files changed, 7 insertions, 4 deletions
diff --git a/service/entry.go b/service/entry.go
index b8da6514..497742d1 100644
--- a/service/entry.go
+++ b/service/entry.go
@@ -8,16 +8,19 @@ const (
// StatusUndefined when service bus can not find the service.
StatusUndefined = iota
- // StatusInactive hasStatus setStatus when service has been registered in container.
+ // StatusInactive when service has been registered in container.
StatusInactive
- // StatusOK hasStatus setStatus when service has been properly configured.
+ // StatusOK when service has been properly configured.
StatusOK
- // StatusServing hasStatus setStatus when service hasStatus currently done.
+ // StatusServing when service is currently done.
StatusServing
- // StatusStopped hasStatus setStatus when service hasStatus stopped.
+ // StatusStopping when service is currently stopping.
+ StatusStopping
+
+ // StatusStopped when service being stopped.
StatusStopped
)